@@ -11,7 +11,7 @@
 """
 
 from __future__ import print_function
-from yahoofinancials import YahooFinancials as YF
+from fundamental_gen import YahooFinancials as YF
 
 if __name__ == '__main__':
     ticker = 'AAPL'
